#Get clinal loci
library(ggplot2)
library(dplyr)
library(reshape2)
library(lme4)

theme_set(theme_bw())
#filter flippy
flipFun <- function(x){
  
  x=data.frame(value=x,Latitude=seq(43,72,1))
  if(x[x$Latitude==72,"value"]<0.5){
    x$value=1-x$value
  }
  
  if(x[x$Latitude==72,"value"]<x[x$Latitude==43,"value"]){
    x$value=1-x$value
  }
  
  return(x[order(x$Latitude),"value"])
}

dat=read.csv("Euro_1773Loci_Latitude.txt",header=T,sep="\t")
head(dat)
testdata=data.frame(x=dat$Latitude,y=1-dat$AY388596_a)

mod=glm(y~x,data=testdata,family=binomial(link="logit"))

moddata=data.frame(x=seq(43,72,1))

modplot=data.frame(x=seq(43,72,1),y=exp(predict(mod,moddata))/(1+exp(predict(mod,moddata))))

plot(y~x,modplot)


glmfun <- function(x){
  Latitudes=c(43.39000, 43.57000, 43.57000, 47.27000, 50.40000, 51.94000, 54.10000, 54.26930, 54.46187, 54.51779, 54.66829, 54.97093, 55.05000, 55.31762, 55.41252,
              55.43468, 55.44979, 55.75000, 56.35412, 56.43677, 56.51542, 56.68700, 56.72376, 56.75000, 56.78329, 57.06050, 57.24469, 57.29003, 57.30756, 57.39552,
              57.40427,57.43309, 57.45086, 57.45315, 57.45914, 57.52369, 57.54411, 57.60851, 57.84205, 57.88607, 58.00049, 58.07580, 58.20170, 58.23000, 58.52000,
              59.04000, 59.52000, 61.10000, 63.34000, 63.75000, 63.93000, 64.28000, 64.57000, 65.00000, 65.81000, 65.83000, 66.27000, 66.95000, 68.88000, 70.50000)
  moddata=data.frame(x=Latitudes,y=x)
  predictdata=data.frame(x=seq(43,72,1))
  mod=glm(y~x,data=moddata,family=binomial(link="logit"))
  #modplot=data.frame(x=seq(0,72,10),y=exp(predict(mod,predictdata))/(1+exp(predict(mod,predictdata))))
  return(exp(predict(mod,predictdata))/(1+exp(predict(mod,predictdata))))
}

testdata=dat[,-c(1,2,grep("Count",colnames(dat)))]

glmout <- as.data.frame(apply(testdata,2,FUN=glmfun))

glmout$Latitude <- seq(43,72,1)


plotdata=melt(glmout,id.vars="Latitude")
plotdata$Clinal="No"

for(i in colnames(testdata)){
  plotdata[plotdata$variable==i,"value"]=flipFun(plotdata[plotdata$variable==i,"value"])
  
  if(plotdata[plotdata$variable==i&plotdata$Latitude==72,"value"]-
     plotdata[plotdata$variable==i&plotdata$Latitude==43,"value"]>0.4{
    plotdata[plotdata$variable==i,"Clinal"]="Yes"
  }
  
}

yy<-filter(plotdata,Clinal=="Yes") #dplyr way
europelatitudinaloutliers<-as.vector(unique(yy$variable))

ggplot(plotdata,aes(x=Latitude,y=value,group=variable,col=Clinal))+geom_line(size=0.5)+
  theme_bw()+
  scale_color_manual(values=c("black", "red"))+
  theme(legend.position="none")+scale_y_continuous(limits=c(0,1))+
  labs(x=expression("Latitude"~degree~"N"),y="Allele frequency")+facet_grid(~Clinal)

#Overall analysis

Odata <- filter(plotdata,Clinal=="Yes")
eurolatclinal<-as.vector(unique(Odata$variable))
write.table(eurolatclinal,"Final_Europe_ClinalLoci.txt",quote=F, row.names = F)

ModGlobal <- glm(value~Latitude,data=Odata,family=binomial(link="logit"))
#ModGlobal2 <- glmer(value~Latitude+1|variable,data=Odata,family=binomial(link="logit"))
OverallFit <- predict(ModGlobal,newdata=data.frame(Latitude=seq(43,72,1)),se.fit = TRUE)
GobalPlotData <- data.frame(Latitude=seq(43,72,1),value=exp(OverallFit$fit)/(1+exp(OverallFit$fit)),
                            se=OverallFit$se.fit)

p=0.5 # inflection point at 50% prob
fit_inflect <- (log(p/(1-p)) - coef(ModGlobal)[1]) / coef(ModGlobal)[2] #58.8 degrees

ggplot()+
  geom_line(aes(x=Latitude,y=value,group=variable),filter(plotdata,Clinal=="Yes"),lwd=0.2,col="grey10")+
  #geom_line(aes(x=Latitude,y=value,group=variable),filter(plotdata,Clinal=="Yes"),lwd=0.4)+
  geom_line(aes(x=Latitude,y=value),GobalPlotData,lwd=2)+
  geom_line(aes(x=Latitude,y=value+se),GobalPlotData,lty=2,lwd=1.5)+
  geom_line(aes(x=Latitude,y=value-se),GobalPlotData,lty=2,lwd=1.5)+theme_bw()+
  scale_y_continuous(limits=c(0,1))+geom_vline(xintercept=fit_inflect)


theme(legend.position="none")+scale_y_continuous(limits=c(0,1))+
  labs(x="Latitude (km)",y="Allele frequency")+facet_grid(~Clinal)





#######################################################################################
##################North America Outliers##############################################
#############################################################################
#filter flippy
flipFun1 <- function(x){
  
  x=data.frame(value=x,Latitude=seq(44,60,1))
  if(x[x$Latitude==60,"value"]<0.5){
    x$value=1-x$value
  }
  
  if(x[x$Latitude==60,"value"]<x[x$Latitude==44,"value"]){
    x$value=1-x$value
  }
  
  return(x[order(x$Latitude),"value"])
}




dat1=read.table("NA_1773Loci_Latitude.txt",header=T,sep="\t")

testdata1=data.frame(x=dat1$Latitude,y=1-dat1$AY388596_a)

mod1=glm(y~x,data=testdata1,family=binomial(link="logit"))

moddata1=data.frame(x=seq(44,60,1))

modplot1=data.frame(x=seq(44,60,1),y=exp(predict(mod1,moddata1))/(1+exp(predict(mod1,moddata1))))

plot(y~x,modplot1)


glmfun1 <- function(x){
  Latitudes=c( 44.13000, 44.37000, 44.60000, 45.08000, 45.10000, 45.14000, 45.38000, 45.42000, 45.62000, 45.94000, 45.96000, 46.30000, 46.43000,
               46.48000, 46.77000, 46.77000, 46.79000, 46.87000, 47.17000, 47.22000, 47.23000, 47.26000, 47.43000, 47.65000, 47.68000, 47.7300,
               47.80000, 47.82000, 47.91000, 47.92000, 47.97000, 48.20000, 48.25000, 48.77000, 48.85000, 49.08000, 49.12000, 49.13000, 49.28000,
               49.42000, 49.42000, 49.47000, 50.12000, 50.20000, 50.20000, 50.27000, 50.28000, 50.77000, 51.14000, 51.19000, 51.30000, 51.32000,
               51.47000, 51.48467, 51.52628, 53.25389, 53.27753, 53.33778, 53.42000, 53.42408, 53.48200, 53.53333, 53.56667, 53.62011, 53.73792,
               53.79000, 53.86500, 53.86806, 53.92700, 54.23778, 55.56836, 58.53000, 58.77000, 58.82000)
  moddata1=data.frame(x=Latitudes,y=x)
  predictdata1=data.frame(x=seq(44,60,1))
  mod1=glm(y~x,data=moddata1,family=binomial(link="logit"))
  #modplot=data.frame(x=seq(0,3000,10),y=exp(predict(mod,predictdata))/(1+exp(predict(mod,predictdata))))
  return(exp(predict(mod1,predictdata1))/(1+exp(predict(mod1,predictdata1))))
}

testdata1=dat1[,-c(1,2,grep("Count",colnames(dat1)))]

glmout1 <- as.data.frame(apply(testdata1,2,FUN=glmfun1))

glmout1$Latitude <- seq(44,60,1)


plotdata1=melt(glmout1,id.vars="Latitude")
plotdata1$Clinal="No"

for(i in colnames(testdata1)){
  plotdata1[plotdata1$variable==i,"value"]=flipFun1(plotdata1[plotdata1$variable==i,"value"])
  
  if(plotdata1[plotdata1$variable==i&plotdata1$Latitude==60,"value"]-
     plotdata1[plotdata1$variable==i&plotdata1$Latitude==44,"value"]>0.3{
    plotdata1[plotdata1$variable==i,"Clinal"]="Yes"
  }
  
}

tt<-filter(plotdata1,Clinal=="Yes") #dplyr way
NAlatitudinaloutliers<-as.vector(unique(tt$variable))
ttt


ggplot(plotdata1,aes(x=Latitude,y=value,group=variable,col=Clinal))+geom_line(size=0.5)+
  theme_bw()+
  scale_color_manual(values=c("black", "red"))+
  theme(legend.position="none")+scale_y_continuous(limits=c(0,1))+
  labs(x=expression("Latitude"~degree~"N"),y="Allele frequency")+facet_grid(~Clinal)

#Overall analysis

Odata1 <- filter(plotdata1,Clinal=="Yes")
latclinalNA<-as.vector(unique(Odata1$variable))
write.table(latclinalNA,"Final_NA_ClinalLoci.txt",quote = F,row.names = F)


ModGlobal1 <- glm(value~Latitude,data=Odata1,family=binomial(link="logit"))
#ModGlobal2 <- glmer(value~Latitude+1|variable,data=Odata,family=binomial(link="logit"))
OverallFit1 <- predict(ModGlobal1,newdata=data.frame(Latitude=seq(44,60,1)),se.fit = TRUE)
GobalPlotData1 <- data.frame(Latitude=seq(44,60,1),value=exp(OverallFit1$fit)/(1+exp(OverallFit1$fit)),
                             se=OverallFit1$se.fit)

p=0.5 # inflection point at 50% prob
fit_inflect <- (log(p/(1-p)) - coef(ModGlobal1)[1]) / coef(ModGlobal1)[2] #53.36 degrees

ggplot()+
  geom_line(aes(x=Latitude,y=value,group=variable),filter(plotdata1,Clinal=="Yes"),lwd=0.2,col="grey10")+
  #geom_line(aes(x=Latitude,y=value,group=variable),filter(plotdata,Clinal=="Yes"),lwd=0.4)+
  geom_line(aes(x=Latitude,y=value),GobalPlotData1,lwd=2)+
  geom_line(aes(x=Latitude,y=value+se),GobalPlotData1,lty=2,lwd=1.5)+
  geom_line(aes(x=Latitude,y=value-se),GobalPlotData1,lty=2,lwd=1.5)+
  theme_bw()+
  scale_y_continuous(limits=c(0,1))+geom_vline(xintercept=fit_inflect)


