
##load libraries
library(dplyr)
library(lme4)
library(lmerTest)
library(ggplot2)
library(reshape2)
library(gridExtra)
library(grid)
library(sjPlot)
library(plotROC)
library(pROC)


NAdata <- read.csv("NEW_NorthAmerica_AllClinalData.csv")
EUdata <- read.csv("NEW_European_AllClinalData.csv")

#EUdata[which(EUdata$AnnualRainfall>1500), ]
## Model Clines (NA) --------------

Vars <- c("Cont","Lat","Distance","STRUCTURE","STRUCTURE_SD","STRUCTURE_SE","DAPC","DAPC_SD","DAPC_SE","SPCA","SPCA_SD","SPCA_SE")

EUdata$Cont <- "Europe"
NAdata$Cont <- "North America"

ComboData <- rbind(NAdata[,Vars],EUdata[,Vars])

methods <- c("STRUCTURE","DAPC","SPCA")
independs <- c("Lat","Distance")


glm_output <- NULL
glm_fitdata <- NULL

p=0.5

for (c in c("Europe","North America")){
  
  LoopData <- filter(ComboData,Cont==c)
  
  for (i in methods){
    #set up fractional response
    Success <- round( LoopData[,i],2)*100
    FractionalResponse <- cbind(Success,100-Success);rm(Success)
    
    for (j in independs){
      
      predictor <- as.numeric(LoopData[,j])
      
      mod <- glm(FractionalResponse~predictor,family=binomial(logit)) #GLM fractional
      
      temp_int <- (log(p/(1-p)) - coef(mod)[1]) / coef(mod)[2]#INTERCEPTS
      mod_sum <- summary(mod)
      r2 <- 1-(mod_sum$deviance/mod_sum$null.deviance) #McFadden's Pseudo-R2
      sig <- data.frame(mod_sum$coefficients)[2,4]
      aic <- mod_sum$aic
      out <- data.frame(method = i,independent = j,model="gzlm",int = temp_int,r2=r2,sig=sig,aic=aic,Cont=c,stringsAsFactors = F,row.names = NULL)
      glm_output <- rbind(glm_output,out)
      
      
      #Model the data and extract variability measures
      newdata <- data.frame(predictor=as.numeric(seq(min(predictor,na.rm=T),max(predictor,na.rm=T)),length.out = 2000))
      pred <- as.data.frame(predict(mod,newdata=newdata,type="response",se.fit=T))
      newdata$fit <- pred$fit
      newdata$se <- pred$se
      newdata$Cont <- c
      colnames(newdata)[1] = "predictor"
      newdata$independent <- j
      newdata$method <- i
      
      glm_fitdata <- rbind(glm_fitdata,newdata)
      
    } # end of j independent variables
  }#end of i methods
}#end of c Continents


pstruct <- melt(ComboData[,c("Cont","Lat","Distance","STRUCTURE","STRUCTURE_SD","STRUCTURE_SE")],id.vars=c("Cont","STRUCTURE","STRUCTURE_SD","STRUCTURE_SE"))
pdapc <- melt(ComboData[,c("Cont","Lat","Distance","DAPC","DAPC_SD","DAPC_SE")],id.vars=c("Cont","DAPC","DAPC_SD","DAPC_SE"))
pspca <- melt(ComboData[,c("Cont","Lat","Distance","SPCA","SPCA_SD","SPCA_SE")],id.vars=c("Cont","SPCA","SPCA_SD","SPCA_SE"))

pstruct$method <- "STRUCTURE"
pdapc$method <- "DAPC"
pspca$method <- "SPCA"

colnames(pstruct) <- c("Cont","val","sd","se","independent","value","method")
colnames(pdapc) <- c("Cont","val","sd","se","independent","value","method")
colnames(pspca) <- c("Cont","val","sd","se","independent","value","method")

plotdata <- rbind(pstruct,pdapc,pspca)


#Plot naming
plotdata[plotdata$method == "SPCA","method"] = "sPCA"
glm_output[glm_output$method == "SPCA","method"] = "sPCA"
glm_fitdata[glm_fitdata$method == "SPCA","method"] = "sPCA"

plotdata$method <- factor(plotdata$method,levels=c("STRUCTURE","DAPC","sPCA"))
glm_output$method <- factor(glm_output$method,levels=c("STRUCTURE","DAPC","sPCA"))
glm_fitdata$method <- factor(glm_fitdata$method,levels=c("STRUCTURE","DAPC","sPCA"))

#Have to trick ggplot into plotting all three due to the facet call
IntData <- glm_output[order(glm_output$independent),]
nMods <- nrow(IntData)
InterceptData <- rbind(IntData,IntData,IntData)
InterceptData$method <- rep(c("STRUCTURE","DAPC","sPCA"),each=nMods)
InterceptData$method <- factor(InterceptData$method,levels=c("STRUCTURE","DAPC","sPCA"))



p_Lat <- ggplot()+
  geom_line(data=filter(glm_fitdata,independent=="Lat"),aes(x=predictor,y=fit))+
  geom_line(data=filter(glm_fitdata,independent=="Lat"),aes(x=predictor,y=fit - (1.96 * se)),lty=2)+
  geom_line(data=filter(glm_fitdata,independent=="Lat"),aes(x=predictor,y=fit + (1.96 * se)+1.96*se),lty=2)+
  geom_errorbar(data=filter(plotdata,independent=="Lat"),aes(x=value,ymin=val-se,ymax=val+se),width=0.1)+
  geom_point(data=filter(plotdata,independent=="Lat"),aes(x=value,y=val))+
  geom_vline(data=filter(InterceptData,independent=="Lat"),aes(xintercept=int),colour="grey70",lty=2,lwd=0.4)+
  geom_segment(data=filter(glm_output,independent=="Lat"),aes(y=0.5,yend=0.5,x=-Inf,xend=int),lty=2,colour="grey35")+
  geom_segment(data=filter(glm_output,independent=="Lat"),aes(y=-Inf,yend=0.5,x=int,xend=int),lty=2,colour="grey35")+
  facet_grid(method~Cont,scales="free_x")+
  labs(x=expression(paste("Latitude ",~degree*N,sep="")),
       y=expression(paste("Coefficient  " %+-% "se",sep=" ")))+
  theme_bw()+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_rect(colour = "black", fill = "white"),
        legend.background = element_rect(fill="transparent"),
        legend.position = c(1, 0), 
        legend.justification = c(1, 0),
        legend.title = element_blank(),
        legend.key = element_blank());p_Lat

p_Dist <- ggplot()+
  geom_line(data=filter(glm_fitdata,independent=="Distance"),aes(x=predictor,y=fit))+
  geom_line(data=filter(glm_fitdata,independent=="Distance"),aes(x=predictor,y=fit - (1.96 * se)),lty=2)+
  geom_line(data=filter(glm_fitdata,independent=="Distance"),aes(x=predictor,y=fit + (1.96 * se)+1.96*se),lty=2)+
  geom_errorbar(data=filter(plotdata,independent=="Distance"),aes(x=value,ymin=val-se,ymax=val+se),width=20)+
  geom_point(data=filter(plotdata,independent=="Distance"),aes(x=value,y=val))+
  geom_vline(data=filter(InterceptData,independent=="Distance"),aes(xintercept=int),colour="grey70",lty=2,lwd=0.4)+
  geom_segment(data=filter(glm_output,independent=="Distance"),aes(y=0.5,yend=0.5,x=-Inf,xend=int),lty=2,colour="grey35")+
  geom_segment(data=filter(glm_output,independent=="Distance"),aes(y=-Inf,yend=0.5,x=int,xend=int),lty=2,colour="grey35")+
  facet_grid(method~Cont,scales="free_x")+
  labs(x="Distance from southern range extent (km)",
       y=expression(paste("Coefficient  " %+-% "se",sep=" ")))+
  theme_bw()+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_rect(colour = "black", fill = "white"),
        legend.background = element_rect(fill="transparent"),
        legend.position = c(1, 0), 
        legend.justification = c(1, 0),
        legend.title = element_blank(),
        legend.key = element_blank());p_Dist

ggsave(filename = "Latitude_Cline.png",p_Lat,width=10,height=8)
ggsave("Distance_Cline.png",p_Dist,width=10,height=8)
  
  

########################################################################
#### Cline Environmental Analysis -----------------------------------
########################################################################


NAenvs <- c("Spring","Winter")

NaVars <- c("StationName","Site","Code","STRUCTURE","DAPC","SPCA","Long","Lat","Distance",  
"Average.Annual.Temp", "Winter","Spring","Summer","Fall",      
"AnnualSnowfall","AnnualRainfall","Days..0.C","Days..10.C","Degree.Days..0",     
"Degree.Days..10","Cont")

plot(NAdata$Lat,NAdata$Winter,pch=19,data=NAdata)
abline(lm(NAdata$Winter~NAdata$La))

Merged <- melt(NAdata[,NaVars],id.vars=setdiff(NaVars,c("SPCA","DAPC","STRUCTURE")))

colnames(Merged)[grep("variable",names(Merged))]="method"
colnames(Merged)[grep("value",names(Merged))]="q1"
Merged$method <- as.character(Merged$method)


#Variables of interest for the analysis
Variables <-   c("Spring","Winter")
CleanVars <- c("Spring","Winter")

#Get the limits so the insets can all have the same scale
RangeData <- melt(Merged[,Variables])
maxT <- max(RangeData$value,na.rm=T)
minT <- min(RangeData$value,na.rm=T)

InsetVars <- Variables[order(Variables,decreasing = T)]

Insets <- list()
for (i in 1:length(InsetVars)){
  
  subData <- Merged[,c("Lat",InsetVars[i])]
  colnames(subData)[2] = "value"
  subData$Zone <- "N"
  subData[subData$Lat<50,"Zone"]="S"
  
  subData$Zone <- factor(subData$Zone,levels=c("S","N"))
  
  Insets[[i]] <- ggplot()+
    geom_boxplot(data=subData,aes(x=Zone,y=value))+
    theme_bw()+
    scale_y_continuous(limits=c(minT,maxT),breaks=seq(floor(minT),ceiling(maxT),3))+
    theme(panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank(),
          panel.background = element_blank(),
          plot.background = element_blank(),
          axis.line = element_line(colour = "black"),
          axis.text.x = element_text(size=10,face="bold"))+
    labs(x="",y="")
}


#Define view ports based on a 4 panel figure
vp1 <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.447, 
                y = 0.83)

vp2 <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.917, 
                y = 0.83)

vp3 <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.447, 
                y = 0.36)

vp4 <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.917, 
                y = 0.36)

##METHOD for data analsyis (STRUCTRUE, DAPC, sPCA)
methods <- as.character(unique(Merged$method))
p=0.5
glm_output <- NULL
glm_fitdata <- NULL
#loop for each assignment method
for (m in methods){
  
  method <- m    
  
  #Fit a NLS regression
  Fit_Data <- NULL 
  for (i in Variables){
    
    Success <- round(Merged[Merged$method==m,"q1"],2)*100
    FractionalResponse <- cbind(Success,100-Success);rm(Success)
    
    predictor <- Merged[Merged$method==m,i]
    
    mod <-  glm(FractionalResponse~predictor,family=binomial(logit)) #GLM fractional
    
    
    temp_int <- (log(p/(1-p)) - coef(mod)[1])/coef(mod)[2]#INTERCEPTS
    mod_sum <- summary(mod)
    r2 <- 1-(mod_sum$deviance/mod_sum$null.deviance) #McFadden's Pseudo-R2
    sig <- data.frame(mod_sum$coefficients)[2,4]
    aic <- mod_sum$aic
    out <- data.frame(method = m,independent = i,model="gzlm",int = temp_int,r2=r2,sig=sig,aic=aic,stringsAsFactors = F,row.names = NULL)
    glm_output <- rbind(glm_output,out)
    
  }}
  
    
    #Model the data and extract variability measures
    newdata <- data.frame(predictor=as.numeric(seq(min(predictor,na.rm=T),max(predictor,na.rm=T)),length.out = 2000))
    pred <- as.data.frame(predict(mod,newdata=newdata,type="response",se.fit=T))
    newdata$fit <- pred$fit
    newdata$se <- pred$se
    newdata$upper <- newdata$fit + newdata$se
    newdata$lower <- newdata$fit - newdata$se
    colnames(newdata)[1] = "predictor"
    
    #rm(FractionalResponse,predictor) # clean for next loop
   
    newdata$variable = CleanVars[grep(i,Variables)]
    
    Fit_Data <- rbind(Fit_Data,newdata)


  
  
  FitPlot <- melt(Merged[Merged$method==m,c("q1","Lat",Variables)],id.vars=c("q1","Lat"))
  FitPlot$variable=as.character(FitPlot$variable)
  
  for(i in 1:length(Variables)){
    FitPlot[FitPlot$variable==Variables[i],"variable"]=CleanVars[i]
  }

  
  #Clean up the labels
  
  #Set up plot labels ** make sure these match
  FitPlot$variable <- factor(FitPlot$variable,levels = CleanVars)
  Fit_Data$variable <- factor(Fit_Data$variable,levels = CleanVars)
  
  p1 <- ggplot()+
    geom_point(data=FitPlot,aes(x=value,y=q1,colour=Lat),size=2.5)+
    #geom_errorbar(aes(ymin=q1-Mean_Q_SD,ymax=q1+Mean_Q_SD))+
    geom_line(data=Fit_Data,aes(x=predictor,y=fit))+
    geom_line(data=Fit_Data,aes(x=predictor,y=fit-1.96*se),lty=2)+
    geom_line(data=Fit_Data,aes(x=predictor,y=fit+1.96*se),lty=2)+
    facet_wrap(~variable,ncol=2,scale="free_x")+
    theme_bw()+
    theme(panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank(),
          strip.background = element_rect(colour = "black", fill = "white"),
          legend.position = c(0, 0), 
          legend.justification = c(0, 0),
          legend.background = element_rect(fill="transparent"))+
    labs(x=expression(paste("Temperature ",~degree*C,sep="")),colour=expression(~degree*N))+
    scale_color_gradient(low="#E81014",high="#2892C7")
    #scale_color_gradient(low="grey15",high="grey90")
  
  if(method=="sPCA"){p1 <- p1+labs(y=expression(paste("sPCA lagged axis score  " %+-% "se",sep=" ")))}
  if(method=="DAPC"){p1 <- p1+labs(y=expression(paste("DAPC assignment probability  " %+-% "se",sep=" ")))}
  if(method=="STRUCTURE"){p1 <- p1+labs(y=expression(paste("STRUCTURE admixture coefficient  " %+-% "se",sep=" ")))}
  
  #view plot
  p1
  
  #Add View ports to the plot
  
  png(paste0("NA_TempCorrelations_",method,".png"),height = 636,width=854)
  
  print(p1)
  print(Insets[[2]],vp=vp1)
  print(Insets[[1]],vp=vp2)
  #print(Insets[[3]],vp=vp3)
  #print(Insets[[4]],vp=vp4)
  
  dev.off()
  
  rm(p1,FitPlot,Fit_Data)
  
}


## All methods one Plot ---------------

Fit_Data <- NULL 
for(r in methods){
  for (i in Variables){
    
    Success <- round(Merged[Merged$method==r,"q1"],2)*100
    FractionalResponse <- cbind(Success,100-Success);rm(Success)
    
    predictor <- Merged[Merged$method==r,i]
    
    mod <-  glm(FractionalResponse~predictor,family=binomial(logit)) #GLM fractional
    
    
    
    #Model the data and extract variability measures
    newdata <- data.frame(predictor=as.numeric(seq(min(predictor,na.rm=T),max(predictor,na.rm=T)),length.out = 2000))
    pred <- as.data.frame(predict(mod,newdata=newdata,type="response",se.fit=T))
    newdata$fit <- pred$fit
    newdata$se <- pred$se
    newdata$upper <- newdata$fit + newdata$se
    newdata$lower <- newdata$fit - newdata$se
    colnames(newdata)[1] = "predictor"
    
    newdata$method <- r
    newdata$variable <-  CleanVars[grep(i,Variables)]
    
    Fit_Data <- rbind(Fit_Data,newdata)
  }
}

FitPlot <- melt(Merged[,c("q1","Lat","method",Variables)],id.vars=c("q1","Lat","method"))
FitPlot$variable=as.character(FitPlot$variable)

for(i in 1:length(Variables)){
  FitPlot[FitPlot$variable==Variables[i],"variable"]=CleanVars[i]
}


#Clean up the labels

#Set up plot labels ** make sure these match
FitPlot$variable <- factor(FitPlot$variable,levels = CleanVars)
Fit_Data$variable <- factor(Fit_Data$variable,levels = CleanVars)

pAll <- ggplot()+
  geom_point(data=FitPlot,aes(x=value,y=q1,colour=Lat),size=2.5)+
  geom_line(data=Fit_Data,aes(x=predictor,y=fit,lty=method),colour="grey40",lwd=1.05,show.legend = F)+
  #geom_line(data=Fit_Data,aes(x=TEMP,y=fit-sd,colour=method),lty=2)+
  #geom_line(data=Fit_Data,aes(x=TEMP,y=fit+sd,colour=method),lty=2)+
  facet_wrap(~variable,ncol=2,scale="free_x")+
  theme_bw()+
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        strip.background = element_rect(colour = "black", fill = "white"),
        #legend.position="bottom",
         legend.position = c(0.4, 0.75), 
         legend.justification = c(0, 0),
        legend.background = element_rect(fill="transparent"))+
  labs(x=expression(paste("Temperature ",~degree*C,sep="")),
       colour=expression(~degree*N),
       y="Coefficient")+
  scale_color_gradientn(colours = c("#E81014","deepskyblue","#2892C7"));pAll #low="darkblue, high="cyan"
#low="#E81014",high="#2892C7"


#Add View ports to the plot

vpa <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.11, 
                y = 0.16)

vpb <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.585, 
                y = 0.16)


png("NA_TempCorrelations_ALL_Shorter.png",height = 500*2,width=854*2,res=72*2)

print(pAll)
print(Insets[[2]],vp=vpa)
print(Insets[[1]],vp=vpb)

dev.off()


### Intercepts analysis ---------------
#SPCA_intercepts <- filter(SPCA_intercepts,type=="Neighbourhood by distance")
#SPCA_intercepts <- SPCA_intercepts[,names(Structure_intercepts)]

#InterceptData <- rbind(Structure_intercepts,SPCA_intercepts,DAPC_intercepts)

#ggplot(InterceptData,aes(x=method,y=int))+
  #geom_boxplot()+
 # geom_point(position=position_jitter())+
  #theme_bw()



############################################################################################
#############European Environmental Cline Analyses-------------------------------------
##############################################################################################



EUenvs <- c("Average.Annual.Temp", "Winter","Spring","Summer","Fall",      
            "AnnualRainfall")

EUVars <- c("StationName","Site","Code","STRUCTURE","DAPC","SPCA","Long","Lat","Distance",  
            "Average.Annual.Temp", "Winter","Spring","Summer","Fall",      
            "AnnualRainfall")

#plot(EUdata$Lat,EUdata$Winter,pch=19,data=EUdata)
#abline(lm(EUdata$Winter~EUdata$Lat))

Merged <- melt(EUdata[,EUVars],id.vars=setdiff(EUVars,c("SPCA","DAPC","STRUCTURE")))

colnames(Merged)[grep("variable",names(Merged))]="method"
colnames(Merged)[grep("value",names(Merged))]="q1"
Merged$method <- as.character(Merged$method)


#Make the subplots for insets


#Variables of interest for the analysis
Variables <-   c("Average.Annual.Temp", "Winter","Spring","Summer","Fall",      
                 "AnnualRainfall")
CleanVars <- c("Average.Annual.Temp", "Winter","Spring","Summer","Fall",      
               "AnnualRainfall")

#Get the limits so the insets can all have the same scale
RangeData <- melt(Merged[,Variables])
maxT <- max(RangeData$value,na.rm=T)
minT <- min(RangeData$value,na.rm=T)

InsetVars <- Variables[order(Variables,decreasing = T)]

Insets <- list()
for (i in 1:length(InsetVars)){
  
  subData <- Merged[,c("Lat",InsetVars[i])]
  colnames(subData)[2] = "value"
  subData$Zone <- "N"
  subData[subData$Lat<59,"Zone"]="S"
  
  subData$Zone <- factor(subData$Zone,levels=c("S","N"))
  
  Insets[[i]] <- ggplot()+
    geom_boxplot(data=subData,aes(x=Zone,y=value))+
    theme_bw()+
    scale_y_continuous(limits=c(minT,maxT),breaks=seq(floor(minT),ceiling(maxT),3))+
    theme(panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank(),
          panel.background = element_blank(),
          plot.background = element_blank(),
          axis.line = element_line(colour = "black"),
          axis.text.x = element_text(size=10,face="bold"))+
    labs(x="",y="")
}


#Define view ports based on a 4 panel figure
vp1 <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.447, 
                y = 0.83)

vp2 <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.917, 
                y = 0.83)

vp3 <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.447, 
                y = 0.36)

vp4 <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.917, 
                y = 0.36)

##METHOD for data analsyis (STRUCTRUE, DAPC, sPCA)
methods <- as.character(unique(Merged$method))
p=0.5
glm_output <- NULL
glm_fitdata <- NULL
#loop for each assignment method
for (m in methods){
  
  method <- m    
  
  #Fit a NLS regression
  Fit_Data <- NULL 
  for (i in Variables){
    
    Success <- round(Merged[Merged$method==m,"q1"],2)*100
    FractionalResponse <- cbind(Success,100-Success);rm(Success)
    
    predictor <- Merged[Merged$method==m,i]
    
    mod <-  glm(FractionalResponse~predictor,family=binomial(logit)) #GLM fractional
    
    
    temp_int <- (log(p/(1-p)) - coef(mod)[1])/coef(mod)[2]#INTERCEPTS
    mod_sum <- summary(mod)
    r2 <- 1-(mod_sum$deviance/mod_sum$null.deviance) #McFadden's Pseudo-R2
    sig <- data.frame(mod_sum$coefficients)[2,4]
    aic <- mod_sum$aic
    out <- data.frame(method = m,independent = i,model="gzlm",int = temp_int,r2=r2,sig=sig,aic=aic,stringsAsFactors = F,row.names = NULL)
    glm_output <- rbind(glm_output,out)
    
  }}
    
    #Model the data and extract variability measures
    newdata <- data.frame(predictor=as.numeric(seq(min(predictor,na.rm=T),max(predictor,na.rm=T)),length.out = 2000))
    pred <- as.data.frame(predict(mod,newdata=newdata,type="response",se.fit=T))
    newdata$fit <- pred$fit
    newdata$se <- pred$se
    newdata$upper <- newdata$fit + newdata$se
    newdata$lower <- newdata$fit - newdata$se
    colnames(newdata)[1] = "predictor"
    
    rm(FractionalResponse,predictor) # clean for next loop
    
    newdata$variable = CleanVars[grep(i,Variables)]
    
    Fit_Data <- rbind(Fit_Data,newdata)
  }
  
  
  FitPlot <- melt(Merged[Merged$method==m,c("q1","Lat",Variables)],id.vars=c("q1","Lat"))
  FitPlot$variable=as.character(FitPlot$variable)
  
  for(i in 1:length(Variables)){
    FitPlot[FitPlot$variable==Variables[i],"variable"]=CleanVars[i]
  }
  
  
  #Clean up the labels
  
  #Set up plot labels ** make sure these match
  FitPlot$variable <- factor(FitPlot$variable,levels = CleanVars)
  Fit_Data$variable <- factor(Fit_Data$variable,levels = CleanVars)
  
  p1 <- ggplot()+
    geom_point(data=FitPlot,aes(x=value,y=q1,colour=Lat),size=2.5)+
    #geom_errorbar(aes(ymin=q1-Mean_Q_SD,ymax=q1+Mean_Q_SD))+
    geom_line(data=Fit_Data,aes(x=predictor,y=fit))+
    geom_line(data=Fit_Data,aes(x=predictor,y=fit-1.96*se),lty=2)+
    geom_line(data=Fit_Data,aes(x=predictor,y=fit+1.96*se),lty=2)+
    facet_wrap(~variable,ncol=2,scale="free_x")+
    theme_bw()+
    theme(panel.grid.major = element_blank(), 
          panel.grid.minor = element_blank(),
          strip.background = element_rect(colour = "black", fill = "white"),
          legend.position = c(0, 0), 
          legend.justification = c(0, 0),
          legend.background = element_rect(fill="transparent"))+
    labs(x=expression(paste("Temperature ",~degree*C,sep="")),colour=expression(~degree*N))+
    scale_color_gradient(low="darkblue",high="cyan")
  #scale_color_gradient(low="grey15",high="grey90")
  
  if(method=="sPCA"){p1 <- p1+labs(y=expression(paste("sPCA lagged axis score  " %+-% "se",sep=" ")))}
  if(method=="DAPC"){p1 <- p1+labs(y=expression(paste("DAPC assignment probability  " %+-% "se",sep=" ")))}
  if(method=="STRUCTURE"){p1 <- p1+labs(y=expression(paste("STRUCTURE admixture coefficient  " %+-% "se",sep=" ")))}
  
  #veiw plot
  p1
  
  #Add View ports to the plot
  
  png(paste0("Euro_TempCorrelations_",method,".png"),height = 636,width=854)
  
  print(p1)
  print(Insets[[2]],vp=vp1)
  print(Insets[[1]],vp=vp2)
  #print(Insets[[3]],vp=vp3)
  #print(Insets[[4]],vp=vp4)
  
  dev.off()
  
  rm(p1,FitPlot,Fit_Data)
  
}


## All methods one Plot ---------------

Fit_Data <- NULL 
for(r in methods){
  for (i in Variables){
    
    Success <- round(Merged[Merged$method==r,"q1"],2)*100
    FractionalResponse <- cbind(Success,100-Success);rm(Success)
    
    predictor <- Merged[Merged$method==r,i]
    
    mod <-  glm(FractionalResponse~predictor,family=binomial(logit)) #GLM fractional
    
    #Model the data and extract variability measures
    newdata <- data.frame(predictor=as.numeric(seq(min(predictor,na.rm=T),max(predictor,na.rm=T)),length.out = 2000))
    pred <- as.data.frame(predict(mod,newdata=newdata,type="response",se.fit=T))
    newdata$fit <- pred$fit
    newdata$se <- pred$se
    newdata$upper <- newdata$fit + newdata$se
    newdata$lower <- newdata$fit - newdata$se
    colnames(newdata)[1] = "predictor"
    
    newdata$method <- r
    newdata$variable <-  CleanVars[grep(i,Variables)]
    
    Fit_Data <- rbind(Fit_Data,newdata)
  }
}

FitPlot <- melt(Merged[,c("q1","Lat","method",Variables)],id.vars=c("q1","Lat","method"))
FitPlot$variable=as.character(FitPlot$variable)

for(i in 1:length(Variables)){
  FitPlot[FitPlot$variable==Variables[i],"variable"]=CleanVars[i]
}


#Clean up the labels

#Set up plot labels ** make sure these match
FitPlot$variable <- factor(FitPlot$variable,levels = CleanVars)
Fit_Data$variable <- factor(Fit_Data$variable,levels = CleanVars)

pAll <- ggplot()+
  geom_point(data=FitPlot,aes(x=value,y=q1,colour=Lat),size=2.5)+
  geom_line(data=Fit_Data,aes(x=predictor,y=fit,lty=method),colour="grey40",lwd=1.05,show.legend = F)+
  #geom_line(data=Fit_Data,aes(x=TEMP,y=fit-sd,colour=method),lty=2)+
  #geom_line(data=Fit_Data,aes(x=TEMP,y=fit+sd,colour=method),lty=2)+
  facet_wrap(~variable,ncol=2,scale="free_x")+
  theme_bw()+
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        strip.background = element_rect(colour = "black", fill = "white"),
        #legend.position="bottom",
        legend.position = c(0.4, 0.75), 
        legend.justification = c(0, 0),
        legend.background = element_rect(fill="transparent"))+
  labs(x=expression(paste("Temperature ",~degree*C,sep="")),
       colour=expression(~degree*N),
       y="Coefficient")+
  #scale_color_gradientn(colours = c("#E81014","tomato","#2892C7"))+
  scale_color_gradientn(colours=c("#E81014","tomato","deepskyblue","#2892C7"));pAll


#Add View ports to the plot

vpa <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.11, 
                y = 0.16)

vpb <- viewport(width = 0.15, 
                height = 0.25, 
                x = 0.585, 
                y = 0.16)


png("Europe_TempCorrelations_ALL_Shorter.png",height = 500*2,width=854*2,res=72*2)

print(pAll)
print(Insets[[2]],vp=vpa)
print(Insets[[1]],vp=vpb)

dev.off()
dev.off()





















### Intercepts analysis ---------------
SPCA_intercepts <- filter(SPCA_intercepts,type=="Neighbourhood by distance")
SPCA_intercepts <- SPCA_intercepts[,names(Structure_intercepts)]

InterceptData <- rbind(Structure_intercepts,SPCA_intercepts,DAPC_intercepts)

ggplot(InterceptData,aes(x=method,y=int))+
  #geom_boxplot()+
  geom_point(position=position_jitter())+
  theme_bw()


